@@ -34,10 +34,11 @@ Cache::Cache(const QString &appName): QObject(nullptr)
 {
     m_kns2ComponentName = appName;
 
-    const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QLatin1String("knewstuff3/");
+    const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/knewstuff3/");
     QDir().mkpath(path);
     registryFile = path + appName + ".knsregistry";
     qCDebug(KNEWSTUFFCORE) << "Using registry file: " << registryFile;
+    setProperty("dirty", false); //KF6 make normal variable
 }
 
 QSharedPointer<Cache> Cache::getCache(const QString &appName)
@@ -63,30 +64,30 @@ void Cache::readRegistry()
     readKns2MetaFiles();
 
     QFile f(registryFile);
-    if (!f.open(QIODevice::ReadOnly)) {
+    if (!f.open(QIODevice::ReadOnly | QIODevice::Text)) {
         qWarning() << "The file " << registryFile << " could not be opened.";
         return;
     }
 
-    QDomDocument doc;
-    if (!doc.setContent(&f)) {
+    QXmlStreamReader reader(&f);
+    if (reader.hasError() || !reader.readNextStartElement()) {
         qWarning() << "The file could not be parsed.";
         return;
     }
 
-    QDomElement root = doc.documentElement();
-    if (root.tagName() != QLatin1String("hotnewstuffregistry")) {
+    if (reader.name() != QLatin1String("hotnewstuffregistry")) {
         qWarning() << "The file doesn't seem to be of interest.";
         return;
     }
 
-    QDomElement stuff = root.firstChildElement(QStringLiteral("stuff"));
-    while (!stuff.isNull()) {
+    for (auto token = reader.readNext(); !reader.atEnd(); token = reader.readNext()) {
+        if (token != QXmlStreamReader::StartElement)
+            continue;
         EntryInternal e;
-        e.setEntryXML(stuff);
+        e.setEntryXML(reader);
         e.setSource(EntryInternal::Cache);
         cache.insert(e);
-        stuff = stuff.nextSiblingElement(QStringLiteral("stuff"));
+        Q_ASSERT(reader.tokenType() == QXmlStreamReader::EndElement);
     }
 
     qCDebug(KNEWSTUFFCORE) << "Cache read... entries: " << cache.size();
@@ -96,7 +97,7 @@ void Cache::readKns2MetaFiles()
 {
     qCDebug(KNEWSTUFFCORE) << "Loading KNS2 registry of files for the component: " << m_kns2ComponentName;
 
-    QString realAppName = m_kns2ComponentName.split(':')[0];
+    const auto realAppName = m_kns2ComponentName.splitRef(':')[0];
 
     const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("knewstuff2-entries.registry"), QStandardPaths::LocateDirectory);
     for (QStringList::ConstIterator it = dirs.begin(); it != dirs.end(); ++it) {
@@ -183,6 +184,7 @@ void Cache::readKns2MetaFiles()
 
         }
     }
+    setProperty("dirty", false);
 }
 
 EntryInternal::List Cache::registryForProvider(const QString &providerId)
@@ -198,6 +200,9 @@ EntryInternal::List Cache::registryForProvider(const QString &providerId)
 
 void Cache::writeRegistry()
 {
+    if (!property("dirty").toBool())
+        return;
+
     qCDebug(KNEWSTUFFCORE) << "Write registry";
 
     QFile f(registryFile);
@@ -222,11 +227,12 @@ void Cache::writeRegistry()
     QTextStream metastream(&f);
     metastream << doc.toByteArray();
 
-    f.close();
+    setProperty("dirty", false);
 }
 
 void Cache::registerChangedEntry(const KNSCore::EntryInternal &entry)
 {
+    setProperty("dirty", true);
     cache.insert(entry);
 }
 
