@@ -46,7 +46,7 @@ class DownloadDialogPrivate;
  *
  * \section knsrc knsrc Files
  * The Dialog is configured by a .knsrc file containing the KHotNewStuff configuration.
- * Your application should install a file called: <em>$KDEDIR/share/config/appname.knsrc</em>
+ * Your application should install a file into the XDG configuration location called: <em>/etc/xdg/appname.knsrc</em>
  *
  * The file could look like this for wallpapers:
  * <pre>
@@ -86,7 +86,7 @@ public:
      *
      * @param parent the parent of the dialog
      */
-    explicit DownloadDialog(QWidget *parent = 0);
+    explicit DownloadDialog(QWidget *parent = nullptr);
 
     /**
      * Create a DownloadDialog that lets the user install, update and uninstall
@@ -96,7 +96,7 @@ public:
      * @param configFile the name of the configuration file
      * @param parent the parent of the dialog
      */
-    explicit DownloadDialog(const QString &configFile, QWidget *parent = 0);
+    explicit DownloadDialog(const QString &configFile, QWidget *parent = nullptr);
 
     /**
      * destructor
